@@ -35,7 +35,7 @@ http://tools.ietf.org/html/draft-ietf-appsawg-json-patch-05"""
 
 # Will be parsed by setup.py to determine package metadata
 __author__ = 'Stefan Kögl <stefan@skoegl.net>'
-__version__ = '0.6'
+__version__ = '0.7'
 __website__ = 'https://github.com/stefankoegl/python-json-patch'
 __license__ = 'Modified BSD License'
 
@@ -449,8 +449,13 @@ class TestOperation(PatchOperation):
     def apply(self, obj):
         try:
             subobj, part = self.locate(obj, self.location)
-        except JsonPatchConflict, c:
-            raise JsonPatchTestFailed(str(c))
+        except JsonPatchConflict:
+            exc_info = sys.exc_info()
+            exc = JsonPatchTestFailed(str(exc_info[1]))
+            if sys.version_info >= (3, 0):
+                raise exc.with_traceback(exc_info[2])
+            else:
+                raise exc
 
         val = subobj[part]
 
